@@ -3,7 +3,6 @@ from .datasets import get_dane_data
 from .predictions import predict
 from .performance import compute_f1_scores
 from .networks import GenericNetwork
-import pickle
 import pandas as pd
 from sklearn import preprocessing
 from transformers import AutoModel, AutoTokenizer
@@ -120,70 +119,13 @@ class NERDA():
      
         return df
 
-def train_MBERT(limit = None):
-    name = 'mbert'
-    transformer = 'bert-base-multilingual-uncased'
-    model = NERDA(transformer = transformer,
-                  dataset_training = get_dane_data('train', limit = limit), 
-                  dataset_validation = get_dane_data('validate', limit = limit),
-                  hyperparameters = {'epochs' : 4,
-                                     'warmup_steps' : 500,
-                                     'train_batch_size': 13,
-                                     'learning_rate': 0.0001})
-    model.train()
-    torch.save(model.network.state_dict(), f'{name}_model.bin')
-    dataset_test = get_dane_data('test', limit = limit)
-    f1 = model.evaluate_performance(dataset_test)
-    with open(f'{name}_f1.pickle', 'wb') as f:
-        pickle.dump(f1, f)
-    return model, f1   
-
-def train_DABERT(limit = None):
-    name = 'dabert'
-    transformer = 'DJSammy/bert-base-danish-uncased_BotXO,ai'
-    # TODO: prøv at reducere til 2 epochs.
-    model = NERDA(transformer = transformer,
-                  dataset_training = get_dane_data('train', limit = limit), 
-                  dataset_validation = get_dane_data('validate', limit = limit),
-                  hyperparameters = {'epochs' : 4,
-                                     'warmup_steps' : 500,
-                                     'train_batch_size': 13,
-                                     'learning_rate': 0.0001})
-    model.train()
-    torch.save(model.network.state_dict(), f'{name}_model.bin')
-    dataset_test = get_dane_data('test', limit = limit)
-    f1 = model.evaluate_performance(dataset_test)
-    with open(f'{name}_f1.pickle', 'wb') as f:
-        pickle.dump(f1, f)
-    return model, f1 
-
-def train_ELECTRA(limit = None):
-    name = 'electra'
-    transformer = 'Maltehb/-l-ctra-danish-electra-small-uncased'
-    model = NERDA(transformer = transformer,
-                  dataset_training = get_dane_data('train', limit = limit), 
-                  dataset_validation = get_dane_data('validate', limit = limit),
-                  hyperparameters = {'epochs' : 4,
-                                     'warmup_steps' : 500,
-                                     'train_batch_size': 13,
-                                     'learning_rate': 0.0001})
-    model.train()
-    torch.save(model.network.state_dict(), f'{name}_model.bin')
-    dataset_test = get_dane_data('test', limit = limit)
-    f1 = model.evaluate_performance(dataset_test)
-    with open(f'{name}_f1.pickle', 'wb') as f:
-        pickle.dump(f1, f)
-    return model, f1 
-
 if __name__ == '__main__':
-    from NERDA.models import train_MBERT, train_DABERT, train_ELECTRA
-    # m, f1 = train_MBERT()
-    m, f1 = train_DABERT()
-    m, f1 = train_ELECTRA()
-    t = 'bert-base-multilingual-uncased'
+    from NERDA.models import NERDA
+    from NERDA.datasets import get_dane_data
+    # t = 'bert-base-multilingual-uncased'
     # t = 'Maltehb/-l-ctra-danish-electra-small-uncased'
     # t = 'xlm-roberta-base' # predicter I-MISC
-    # t = 'distilbert-base-multilingual-cased' # TODO: forward tager ikke 'token_type_ids', fejler -> Fjern? 
+    t = 'distilbert-base-multilingual-cased' # TODO: forward tager ikke 'token_type_ids', fejler -> Fjern? 
     N = NERDA(dataset_training = get_dane_data('train', 5),
               dataset_validation = get_dane_data('validate', 5),
               transformer = t)
@@ -204,5 +146,6 @@ if __name__ == '__main__':
     #config = AutoConfig.from_pretrained('Maltehb/-l-ctra-danish-electra-small-uncased')
     #m = AutoConfig.from_pretrained('bert-base-multilingual-uncased')
     
-
+    #s3.Object('larsktest', 'NERDA/electra_model.bin').download_file(
+    #'tester.bin')
         
