@@ -1,5 +1,6 @@
 import torch.nn as nn
 from transformers import AutoConfig
+from .utils import match_kwargs
 
 class GenericNetwork(nn.Module):
     def __init__(self, transformer, device, n_tags, dropout = 0.1):
@@ -15,19 +16,23 @@ class GenericNetwork(nn.Module):
         self.tags = nn.Linear(transformer_config.hidden_size, n_tags)
         self.device = device
 
-    # NOTE: offsets not used as-is, but is expected as output
-    # down-stream. So don't remove! :)
+    # NOTE: offsets are not used in model as-is, but they are expected as output
+    # down-stream. So _DON'T_ remove! :)
     def forward(self, input_ids, masks, token_type_ids, target_tags, offsets):
 
-        # move tensors to device
-        input_ids = input_ids.to(self.device)
-        masks = masks.to(self.device)
-        token_type_ids = token_type_ids.to(self.device)
-        target_tags = target_tags.to(self.device)
+        # TODO: kan gøres endnu bedre med ** og flyt alt til device i et hug.
+        # subset transformer input tensors and move to device
+        transformer_inputs = {
+            'input_ids': input_ids.to(self.device),
+            'masks': masks.to(self.device),
+            'token_type_ids': token_type_ids.to(self.device)
+            }
         
-        # get transformer hidden states
+        # match args with transformer
+        transformer_inputs = match_kwargs(self.transformer.forward, **transformer_inputs)
+           
         # TODO: check hvilke argumenter, transformerne accepterer og match på dem.
-        outputs = self.transformer(input_ids, attention_mask = masks, token_type_ids = token_type_ids)[0]
+        outputs = self.transformer(**transformer_inputs)[0]
 
         # apply drop-out
         outputs = self.dropout(outputs)
@@ -35,4 +40,5 @@ class GenericNetwork(nn.Module):
         # outputs for all labels/tags
         outputs = self.tags(outputs)
 
-        return outputs
\ No newline at end of file
+        return outputs
+
